<!--排查单位查询-筛选弹层-->
<template>
  <van-popup
    v-model="isShow"
    position="bottom"
    :style="{ height: '70%' }"
    round
    @open="open"
  >
    <div class="role-popup">
      <div class="title-box">
        <div class="title-left" @click="isShow = false">取消</div>
        <div class="title-center">选择角色</div>
        <div class="title-right" @click="confirm">确定</div>
      </div>
      <div class="pop-content">
        <van-checkbox-group v-model="result">
          <van-cell-group>
            <van-cell
              v-for="(item, index) in roleList"
              clickable
              :key="item.id"
              :title="`${index + 1}. ${item.name}`"
              @click="toggle(index)"
            >
              <template #right-icon>
                <van-checkbox :name="item" ref="checkboxes" />
              </template>
            </van-cell>
          </van-cell-group>
        </van-checkbox-group>
      </div>
    </div>
  </van-popup>
</template>

<script>
import moment from 'moment'
import {getRolePage} from '@/api/Mobile/personnelManagement'

export default {
  name: 'RolePopup', // 排查单位查询-筛选弹层
  props: {
    // 是否展示弹层
    isShowPopup: {
      default: false,
      type: Boolean
    },
    // 查询对象
    roleName: {
      default: '',
      type: String
    },
    routerQuery: {
      default: () => ({}),
      type: Object
    }
  },
  data() {
    return {
      unitTypePicker: false, // 受检单位类型选择显示
      result: [],
      roleList: []
    }
  },
  computed: {
    isShow: {
      get() {
        return this.isShowPopup
      },
      set(val) {
        this.$emit('update:isShowPopup', val)
      }
    }
  },
  created() {
    this.getRoleData()
  },
  methods: {
    moment,

    // 弹层打开触发
    open() {
      this.result = this.roleList.filter(i => this.roleName.includes(i.name))
    },

    // 查询列表数据（校验成功后）
    searchData() {
      this.$emit('searchData', this.customQueryPrams)
      this.isShow = false // 关闭筛选弹层
    },

    // 确定按钮
    confirm() {
      // 按照角色列表排序
      this.result.sort((a, b) => {
        return this.roleList.findIndex(i => i.name === a.name) - this.roleList.findIndex(i => i.name === b.name)
      })

      this.$emit('confirm', this.result)
      this.isShow = false // 关闭筛选弹层
    },

    // 获取角色列表
    async getRoleData(callback = _ => _) {
      this.roleList = (await getRolePage()).map(i => ({...i, name: i.name + '角色'}))
      callback(this.roleList)
    },

    toggle(index) {
      this.$refs.checkboxes[index].toggle()
    }

  }
}
</script>

<style lang="scss" scoped>


.role-popup {
  display: flex;
  flex-direction: column;
  height: 100%;

  .title-box {
    padding: 15PX;
    display: flex;
    align-items: center;
    justify-content: space-between;

    .title-left {
      font-size: 14PX;
      color: #969799;
      cursor: pointer;
    }

    .title-center {
      color: #323233;
      font-size: 16PX;
    }

    .title-right {
      font-size: 14PX;
      color: #576b95;
      cursor: pointer;
    }
  }

  .pop-content {
    flex: 1;
    overflow: auto;
  }
}

</style>

